@@ -464,15 +464,21 @@ class Commander:
             cur_sub_cmds.append(f"{sub_cmd['name']}:'{sub_cmd['description']}'")
             if "args" in sub_cmd and sub_cmd["args"]:
                 cur_args = """if [[ ${prev} == __sub_cmd__ ]]; then
-                opt_args=(
-                    __sub_cmd_opts__
-                )"""
+    	opt_args=(
+            __sub_cmd_opts__
+        )"""
                 sub_cmd_opts = []
                 for arg in sub_cmd["args"]:
-                    if arg["name"].startswith("-"):
+                    if 'suggestions' in arg:
+                        for i in arg['suggestions']:
+                            sub_cmd_opts.append(f"{i['name']}:'{i.get('description', i['name'])}'")
+                    elif arg["name"].startswith("-"):
                         sub_cmd_opts.append(f"{arg['name']}:'{arg['description']}'")
                 for opt in sub_cmd["options"]:
-                    if opt["name"].startswith("-"):
+                    if 'suggestions' in opt:
+                        for i in opt['suggestions']:
+                            sub_cmd_opts.append(f"{i['name']}:'{i.get('description', i['name'])}'")
+                    elif opt["name"].startswith("-"):
                         sub_cmd_opts.append(f"{opt['name']}:'{opt['description']}'")
                 cur_args = cur_args.replace("__sub_cmd__", sub_cmd["name"])
                 cur_args = cur_args.replace(
